Index: runtime/vm/stub_code.cc |
diff --git a/runtime/vm/stub_code.cc b/runtime/vm/stub_code.cc |
index 5b6a5f54c07d90549c4b2165980cbaa2f45aba6e..0418da89ae315affff01e1eb87ebf8a9f8168c7b 100644 |
--- a/runtime/vm/stub_code.cc |
+++ b/runtime/vm/stub_code.cc |
@@ -91,8 +91,8 @@ void StubCode::VisitObjectPointers(ObjectPointerVisitor* visitor) {} |
bool StubCode::HasBeenInitialized() { |
#if !defined(TARGET_ARCH_DBC) |
- // Use JumpToHandler and InvokeDart as canaries. |
- const StubEntry* entry_1 = StubCode::JumpToFrame_entry(); |
+ // Use JumpToExceptionHandler and InvokeDart as canaries. |
+ const StubEntry* entry_1 = StubCode::JumpToExceptionHandler_entry(); |
const StubEntry* entry_2 = StubCode::InvokeDartCode_entry(); |
return (entry_1 != NULL) && (entry_2 != NULL); |
#else |
@@ -115,11 +115,11 @@ bool StubCode::InInvocationStub(uword pc) { |
} |
-bool StubCode::InJumpToFrameStub(uword pc) { |
+bool StubCode::InJumpToExceptionHandlerStub(uword pc) { |
#if !defined(TARGET_ARCH_DBC) |
ASSERT(HasBeenInitialized()); |
- uword entry = StubCode::JumpToFrame_entry()->EntryPoint(); |
- uword size = StubCode::JumpToFrameSize(); |
+ uword entry = StubCode::JumpToExceptionHandler_entry()->EntryPoint(); |
+ uword size = StubCode::JumpToExceptionHandlerSize(); |
return (pc >= entry) && (pc < (entry + size)); |
#else |
// This stub does not exist on DBC. |